@@ -145,7 +145,9 @@ sub app_load_plugins {
         }
         catch {
             $self->app_log->warn("Could not load plugin $plugin!\n$_");
-        }
+            next;
+        };
+        $self->app_log->info('Loaded plugin '.$plugin);
     }
 
 }
